@@ -1,6 +1,4 @@
 
-# $rcs = ' $Id: Session.pm,v 1.63 2013/08/21 01:52:48 Martin Exp $ ' ;
-
 =head1 COPYRIGHT
 
                 Copyright (C) 2002-present Martin Thurn
@@ -63,7 +61,7 @@ use constant DEBUG_WATCH => 0;
 use constant DEBUG_READ_LOCAL_FILES => 0;
 
 our
-$VERSION = do { my @r = (q$Revision: 1.63 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = 1.65;
 
 sub _debug
   {
@@ -259,8 +257,8 @@ sub fetch_any_ebay_page
     print STDERR " DDD parsing ebay sign-in page...\n" if DEBUG_FETCH;
     # Parse the <FORM> elements:
     my @aoForm = HTML::Form->parse($sPage, $self->response->base);
-    # As of August 2013, the sign-in form is the second one on the page:
-    my $oForm = $aoForm[1];
+    # As of August 2014, the sign-in form is the first one on the page:
+    my $oForm = $aoForm[0];
     unless (ref $oForm)
       {
       print STDERR " EEE eBay sign-in page contained no <FORM> element!\n" if DEBUG_FETCH;
@@ -421,7 +419,7 @@ sub watchlist_auctions
     close PAGE or warn;
     } # if
   _debug " DDD   start parsing webpage...\n" if DEBUG_WATCH;
-  Date_Init('TZ=US/Pacific');
+  # Date_Init('TZ=US/Pacific');
   # Our return value, a list of WWW::Search::Result objects:
   my @aoWSR;
 
@@ -539,7 +537,7 @@ sub selling_auctions
     close PAGE or warn;
     } # if
   _debug " DDD   start parsing webpage...\n" if DEBUG_SELLING;
-  Date_Init('TZ=US/Pacific');
+  # Date_Init('TZ=US/Pacific');
   # Our return value, a list of WWW::Ebay::Listing objects:
   my @aoWEL;
 
@@ -717,7 +715,7 @@ sub sold_auctions
     close PAGE or warn;
     } # if
   _debug " DDD   start parsing webpage...\n" if DEBUG_SOLD;
-  Date_Init('TZ=US/Pacific');
+  # Date_Init('TZ=US/Pacific');
   # Our return value, a list of WWW::Ebay::Listing objects:
   my $oTree;
   if (ref $self->{_selling_tree})
@@ -891,7 +889,7 @@ sub unsold_auctions
     close PAGE or warn;
     } # if
   _debug " DDD   start parsing webpage...\n" if DEBUG_UNSOLD;
-  Date_Init('TZ=US/Pacific');
+  # Date_Init('TZ=US/Pacific');
   # Our return value, a list of WWW::Ebay::Listing objects:
   my @aoWEL;
 
